use clap::{App, Arg, SubCommand, ArgMatches};

use crate::commands;
use crate::commands::remote::RemoteArgs;

pub fn create() -> App<'static, 'static> {
    SubCommand::with_name("remote")
        .about("Manage set of tracked repositories")
        .subcommand(
            SubCommand::with_name("add")
            .arg(
                Arg::with_name("name")
                .required(true)
                .multiple(false)
                .takes_value(true)
                .value_name("NAME")
                .help("The name of the remote"),
                )
            .arg(
                Arg::with_name("url")
                .required(true)
                .multiple(false)
                .takes_value(true)
                .value_name("URL")
                .help("The url of the remote"),
                )
            .about("Add a new remote to this repository")
            )
}

pub fn handler(args: &ArgMatches<'_>) {
    match args.subcommand() {
        ("add", Some(add_matches)) => {
            commands::remote::remote_add(RemoteArgs {
                name: add_matches.values_of("name"),
                url: add_matches.values_of("url"),
            });
        }
        _ => println!("Invalid or missing subcommand for 'remote'"),
    }
}
